# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_identities_get200_response_identities_inner import ApiV1IdentitiesGet200ResponseIdentitiesInner  # noqa: E501

class TestApiV1IdentitiesGet200ResponseIdentitiesInner(unittest.TestCase):
    """ApiV1IdentitiesGet200ResponseIdentitiesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1IdentitiesGet200ResponseIdentitiesInner:
        """Test ApiV1IdentitiesGet200ResponseIdentitiesInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1IdentitiesGet200ResponseIdentitiesInner`
        """
        model = ApiV1IdentitiesGet200ResponseIdentitiesInner()  # noqa: E501
        if include_optional:
            return ApiV1IdentitiesGet200ResponseIdentitiesInner(
                id = '',
                role = '',
                role_id = '',
                org_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                identity_id = '',
                custom_role = infisicalapi_client.models._api_v1_organization__organization_id__groups_get_200_response_groups_inner_custom_role._api_v1_organization__organizationId__groups_get_200_response_groups_inner_customRole(
                    id = '', 
                    name = '', 
                    slug = '', 
                    permissions = null, 
                    description = '', ),
                identity = infisicalapi_client.models._api_v1_identities_get_200_response_identities_inner_identity._api_v1_identities_get_200_response_identities_inner_identity(
                    name = '', 
                    id = '', 
                    auth_method = '', )
            )
        else:
            return ApiV1IdentitiesGet200ResponseIdentitiesInner(
                id = '',
                role = '',
                org_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                identity_id = '',
                identity = infisicalapi_client.models._api_v1_identities_get_200_response_identities_inner_identity._api_v1_identities_get_200_response_identities_inner_identity(
                    name = '', 
                    id = '', 
                    auth_method = '', ),
        )
        """

    def testApiV1IdentitiesGet200ResponseIdentitiesInner(self):
        """Test ApiV1IdentitiesGet200ResponseIdentitiesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

class ApiV1SsoOidcConfigPatchRequest(BaseModel):
    """
    ApiV1SsoOidcConfigPatchRequest
    """
    allowed_email_domains: Optional[StrictStr] = Field(default='', alias="allowedEmailDomains")
    discovery_url: Optional[StrictStr] = Field(default=None, alias="discoveryURL")
    configuration_type: Optional[StrictStr] = Field(default=None, alias="configurationType")
    issuer: Optional[StrictStr] = None
    authorization_endpoint: Optional[StrictStr] = Field(default=None, alias="authorizationEndpoint")
    jwks_uri: Optional[StrictStr] = Field(default=None, alias="jwksUri")
    token_endpoint: Optional[StrictStr] = Field(default=None, alias="tokenEndpoint")
    userinfo_endpoint: Optional[StrictStr] = Field(default=None, alias="userinfoEndpoint")
    client_id: Optional[StrictStr] = Field(default=None, alias="clientId")
    client_secret: Optional[StrictStr] = Field(default=None, alias="clientSecret")
    is_active: Optional[StrictBool] = Field(default=None, alias="isActive")
    org_slug: StrictStr = Field(default=..., alias="orgSlug")
    __properties = ["allowedEmailDomains", "discoveryURL", "configurationType", "issuer", "authorizationEndpoint", "jwksUri", "tokenEndpoint", "userinfoEndpoint", "clientId", "clientSecret", "isActive", "orgSlug"]

    @validator('configuration_type')
    def configuration_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('custom', 'discoveryURL'):
            raise ValueError("must be one of enum values ('custom', 'discoveryURL')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SsoOidcConfigPatchRequest:
        """Create an instance of ApiV1SsoOidcConfigPatchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SsoOidcConfigPatchRequest:
        """Create an instance of ApiV1SsoOidcConfigPatchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SsoOidcConfigPatchRequest.parse_obj(obj)

        _obj = ApiV1SsoOidcConfigPatchRequest.parse_obj({
            "allowed_email_domains": obj.get("allowedEmailDomains") if obj.get("allowedEmailDomains") is not None else '',
            "discovery_url": obj.get("discoveryURL"),
            "configuration_type": obj.get("configurationType"),
            "issuer": obj.get("issuer"),
            "authorization_endpoint": obj.get("authorizationEndpoint"),
            "jwks_uri": obj.get("jwksUri"),
            "token_endpoint": obj.get("tokenEndpoint"),
            "userinfo_endpoint": obj.get("userinfoEndpoint"),
            "client_id": obj.get("clientId"),
            "client_secret": obj.get("clientSecret"),
            "is_active": obj.get("isActive"),
            "org_slug": obj.get("orgSlug")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from infisicalapi_client.models.api_v1_secret_imports_post_request_import import ApiV1SecretImportsPostRequestImport

class ApiV1SecretImportsPostRequest(BaseModel):
    """
    ApiV1SecretImportsPostRequest
    """
    workspace_id: StrictStr = Field(default=..., alias="workspaceId", description="The ID of the project you are working in.")
    environment: StrictStr = Field(default=..., description="The slug of the environment to import into.")
    path: Optional[StrictStr] = Field(default='/', description="The path to import into.")
    var_import: ApiV1SecretImportsPostRequestImport = Field(default=..., alias="import")
    is_replication: Optional[StrictBool] = Field(default=False, alias="isReplication", description="When true, secrets from the source will be automatically sent to the destination. If approval policies exist at the destination, the secrets will be sent as approval requests instead of being applied immediately.")
    __properties = ["workspaceId", "environment", "path", "import", "isReplication"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretImportsPostRequest:
        """Create an instance of ApiV1SecretImportsPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_import
        if self.var_import:
            _dict['import'] = self.var_import.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretImportsPostRequest:
        """Create an instance of ApiV1SecretImportsPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretImportsPostRequest.parse_obj(obj)

        _obj = ApiV1SecretImportsPostRequest.parse_obj({
            "workspace_id": obj.get("workspaceId"),
            "environment": obj.get("environment"),
            "path": obj.get("path") if obj.get("path") is not None else '/',
            "var_import": ApiV1SecretImportsPostRequestImport.from_dict(obj.get("import")) if obj.get("import") is not None else None,
            "is_replication": obj.get("isReplication") if obj.get("isReplication") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictStr, confloat, conint, conlist, validator

class ApiV1AccessApprovalsPoliciesPostRequest(BaseModel):
    """
    ApiV1AccessApprovalsPoliciesPostRequest
    """
    project_slug: StrictStr = Field(default=..., alias="projectSlug")
    name: Optional[StrictStr] = None
    secret_path: Optional[StrictStr] = Field(default='/', alias="secretPath")
    environment: StrictStr = Field(...)
    approvers: conlist(StrictStr, min_items=1) = Field(...)
    approvals: Optional[Union[confloat(ge=1, strict=True), conint(ge=1, strict=True)]] = 1
    enforcement_level: Optional[StrictStr] = Field(default='hard', alias="enforcementLevel")
    __properties = ["projectSlug", "name", "secretPath", "environment", "approvers", "approvals", "enforcementLevel"]

    @validator('enforcement_level')
    def enforcement_level_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('hard', 'soft'):
            raise ValueError("must be one of enum values ('hard', 'soft')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AccessApprovalsPoliciesPostRequest:
        """Create an instance of ApiV1AccessApprovalsPoliciesPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AccessApprovalsPoliciesPostRequest:
        """Create an instance of ApiV1AccessApprovalsPoliciesPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AccessApprovalsPoliciesPostRequest.parse_obj(obj)

        _obj = ApiV1AccessApprovalsPoliciesPostRequest.parse_obj({
            "project_slug": obj.get("projectSlug"),
            "name": obj.get("name"),
            "secret_path": obj.get("secretPath") if obj.get("secretPath") is not None else '/',
            "environment": obj.get("environment"),
            "approvers": obj.get("approvers"),
            "approvals": obj.get("approvals") if obj.get("approvals") is not None else 1,
            "enforcement_level": obj.get("enforcementLevel") if obj.get("enforcementLevel") is not None else 'hard'
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Optional
from pydantic import BaseModel, Field
from infisicalapi_client.models.api_v1_dynamic_secrets_get200_response_dynamic_secrets_inner import ApiV1DynamicSecretsGet200ResponseDynamicSecretsInner
from infisicalapi_client.models.api_v1_dynamic_secrets_name_leases_get200_response_leases_inner import ApiV1DynamicSecretsNameLeasesGet200ResponseLeasesInner

class ApiV1DynamicSecretsLeasesPost200Response(BaseModel):
    """
    ApiV1DynamicSecretsLeasesPost200Response
    """
    lease: ApiV1DynamicSecretsNameLeasesGet200ResponseLeasesInner = Field(...)
    dynamic_secret: ApiV1DynamicSecretsGet200ResponseDynamicSecretsInner = Field(default=..., alias="dynamicSecret")
    data: Optional[Any] = None
    __properties = ["lease", "dynamicSecret", "data"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1DynamicSecretsLeasesPost200Response:
        """Create an instance of ApiV1DynamicSecretsLeasesPost200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of lease
        if self.lease:
            _dict['lease'] = self.lease.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dynamic_secret
        if self.dynamic_secret:
            _dict['dynamicSecret'] = self.dynamic_secret.to_dict()
        # set to None if data (nullable) is None
        # and __fields_set__ contains the field
        if self.data is None and "data" in self.__fields_set__:
            _dict['data'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1DynamicSecretsLeasesPost200Response:
        """Create an instance of ApiV1DynamicSecretsLeasesPost200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1DynamicSecretsLeasesPost200Response.parse_obj(obj)

        _obj = ApiV1DynamicSecretsLeasesPost200Response.parse_obj({
            "lease": ApiV1DynamicSecretsNameLeasesGet200ResponseLeasesInner.from_dict(obj.get("lease")) if obj.get("lease") is not None else None,
            "dynamic_secret": ApiV1DynamicSecretsGet200ResponseDynamicSecretsInner.from_dict(obj.get("dynamicSecret")) if obj.get("dynamicSecret") is not None else None,
            "data": obj.get("data")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post200_response import ApiV1WorkspaceProjectSlugRolesPost200Response  # noqa: E501

class TestApiV1WorkspaceProjectSlugRolesPost200Response(unittest.TestCase):
    """ApiV1WorkspaceProjectSlugRolesPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1WorkspaceProjectSlugRolesPost200Response:
        """Test ApiV1WorkspaceProjectSlugRolesPost200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1WorkspaceProjectSlugRolesPost200Response`
        """
        model = ApiV1WorkspaceProjectSlugRolesPost200Response()  # noqa: E501
        if include_optional:
            return ApiV1WorkspaceProjectSlugRolesPost200Response(
                role = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role._api_v1_workspace__projectSlug__roles_post_200_response_role(
                    id = '', 
                    name = '', 
                    description = '', 
                    slug = '', 
                    permissions = [
                        infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner(
                            subject = null, 
                            action = null, 
                            conditions = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner_conditions._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner_conditions(
                                environment = '', 
                                secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner_conditions_secretPath(
                                    __glob = '0', ), ), )
                        ], 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    project_id = '', )
            )
        else:
            return ApiV1WorkspaceProjectSlugRolesPost200Response(
                role = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role._api_v1_workspace__projectSlug__roles_post_200_response_role(
                    id = '', 
                    name = '', 
                    description = '', 
                    slug = '', 
                    permissions = [
                        infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner(
                            subject = null, 
                            action = null, 
                            conditions = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner_conditions._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner_conditions(
                                environment = '', 
                                secret_path = infisicalapi_client.models._api_v1_workspace__project_slug__roles_post_200_response_role_permissions_inner_conditions_secret_path._api_v1_workspace__projectSlug__roles_post_200_response_role_permissions_inner_conditions_secretPath(
                                    __glob = '0', ), ), )
                        ], 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    project_id = '', ),
        )
        """

    def testApiV1WorkspaceProjectSlugRolesPost200Response(self):
        """Test ApiV1WorkspaceProjectSlugRolesPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_workspace_workspace_id_audit_logs_get200_response_audit_logs_inner import ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner  # noqa: E501

class TestApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner(unittest.TestCase):
    """ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner:
        """Test ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner`
        """
        model = ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner()  # noqa: E501
        if include_optional:
            return ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner(
                id = '',
                ip_address = '',
                user_agent = '',
                user_agent_type = '',
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                org_id = '',
                project_id = '',
                event = infisicalapi_client.models._api_v1_workspace__workspace_id__audit_logs_get_200_response_audit_logs_inner_event._api_v1_workspace__workspaceId__audit_logs_get_200_response_auditLogs_inner_event(
                    type = '', 
                    metadata = null, ),
                actor = infisicalapi_client.models._api_v1_workspace__workspace_id__audit_logs_get_200_response_audit_logs_inner_event._api_v1_workspace__workspaceId__audit_logs_get_200_response_auditLogs_inner_event(
                    type = '', 
                    metadata = null, )
            )
        else:
            return ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner(
                id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                event = infisicalapi_client.models._api_v1_workspace__workspace_id__audit_logs_get_200_response_audit_logs_inner_event._api_v1_workspace__workspaceId__audit_logs_get_200_response_auditLogs_inner_event(
                    type = '', 
                    metadata = null, ),
                actor = infisicalapi_client.models._api_v1_workspace__workspace_id__audit_logs_get_200_response_audit_logs_inner_event._api_v1_workspace__workspaceId__audit_logs_get_200_response_auditLogs_inner_event(
                    type = '', 
                    metadata = null, ),
        )
        """

    def testApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner(self):
        """Test ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from infisicalapi_client.models.api_v1_scim_scim_tokens_get200_response_scim_tokens_inner import ApiV1ScimScimTokensGet200ResponseScimTokensInner

class ApiV1ScimScimTokensGet200Response(BaseModel):
    """
    ApiV1ScimScimTokensGet200Response
    """
    scim_tokens: conlist(ApiV1ScimScimTokensGet200ResponseScimTokensInner) = Field(default=..., alias="scimTokens")
    __properties = ["scimTokens"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1ScimScimTokensGet200Response:
        """Create an instance of ApiV1ScimScimTokensGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in scim_tokens (list)
        _items = []
        if self.scim_tokens:
            for _item in self.scim_tokens:
                if _item:
                    _items.append(_item.to_dict())
            _dict['scimTokens'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1ScimScimTokensGet200Response:
        """Create an instance of ApiV1ScimScimTokensGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1ScimScimTokensGet200Response.parse_obj(obj)

        _obj = ApiV1ScimScimTokensGet200Response.parse_obj({
            "scim_tokens": [ApiV1ScimScimTokensGet200ResponseScimTokensInner.from_dict(_item) for _item in obj.get("scimTokens")] if obj.get("scimTokens") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class ApiV1SecretSharingGet200ResponseSecretsInner(BaseModel):
    """
    ApiV1SecretSharingGet200ResponseSecretsInner
    """
    id: StrictStr = Field(...)
    encrypted_value: StrictStr = Field(default=..., alias="encryptedValue")
    iv: StrictStr = Field(...)
    tag: StrictStr = Field(...)
    hashed_hex: StrictStr = Field(default=..., alias="hashedHex")
    expires_at: datetime = Field(default=..., alias="expiresAt")
    user_id: Optional[StrictStr] = Field(default=None, alias="userId")
    org_id: Optional[StrictStr] = Field(default=None, alias="orgId")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    expires_after_views: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="expiresAfterViews")
    access_type: Optional[StrictStr] = Field(default='anyone', alias="accessType")
    name: Optional[StrictStr] = None
    last_viewed_at: Optional[datetime] = Field(default=None, alias="lastViewedAt")
    __properties = ["id", "encryptedValue", "iv", "tag", "hashedHex", "expiresAt", "userId", "orgId", "createdAt", "updatedAt", "expiresAfterViews", "accessType", "name", "lastViewedAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretSharingGet200ResponseSecretsInner:
        """Create an instance of ApiV1SecretSharingGet200ResponseSecretsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if user_id (nullable) is None
        # and __fields_set__ contains the field
        if self.user_id is None and "user_id" in self.__fields_set__:
            _dict['userId'] = None

        # set to None if org_id (nullable) is None
        # and __fields_set__ contains the field
        if self.org_id is None and "org_id" in self.__fields_set__:
            _dict['orgId'] = None

        # set to None if expires_after_views (nullable) is None
        # and __fields_set__ contains the field
        if self.expires_after_views is None and "expires_after_views" in self.__fields_set__:
            _dict['expiresAfterViews'] = None

        # set to None if name (nullable) is None
        # and __fields_set__ contains the field
        if self.name is None and "name" in self.__fields_set__:
            _dict['name'] = None

        # set to None if last_viewed_at (nullable) is None
        # and __fields_set__ contains the field
        if self.last_viewed_at is None and "last_viewed_at" in self.__fields_set__:
            _dict['lastViewedAt'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretSharingGet200ResponseSecretsInner:
        """Create an instance of ApiV1SecretSharingGet200ResponseSecretsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretSharingGet200ResponseSecretsInner.parse_obj(obj)

        _obj = ApiV1SecretSharingGet200ResponseSecretsInner.parse_obj({
            "id": obj.get("id"),
            "encrypted_value": obj.get("encryptedValue"),
            "iv": obj.get("iv"),
            "tag": obj.get("tag"),
            "hashed_hex": obj.get("hashedHex"),
            "expires_at": obj.get("expiresAt"),
            "user_id": obj.get("userId"),
            "org_id": obj.get("orgId"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "expires_after_views": obj.get("expiresAfterViews"),
            "access_type": obj.get("accessType") if obj.get("accessType") is not None else 'anyone',
            "name": obj.get("name"),
            "last_viewed_at": obj.get("lastViewedAt")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1OrganizationGet200ResponseOrganizationsInner(BaseModel):
    """
    ApiV1OrganizationGet200ResponseOrganizationsInner
    """
    id: StrictStr = Field(...)
    name: StrictStr = Field(...)
    customer_id: Optional[StrictStr] = Field(default=None, alias="customerId")
    slug: StrictStr = Field(...)
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    auth_enforced: Optional[StrictBool] = Field(default=False, alias="authEnforced")
    scim_enabled: Optional[StrictBool] = Field(default=False, alias="scimEnabled")
    kms_default_key_id: Optional[StrictStr] = Field(default=None, alias="kmsDefaultKeyId")
    kms_encrypted_data_key: Optional[Any] = Field(default=None, alias="kmsEncryptedDataKey")
    __properties = ["id", "name", "customerId", "slug", "createdAt", "updatedAt", "authEnforced", "scimEnabled", "kmsDefaultKeyId", "kmsEncryptedDataKey"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1OrganizationGet200ResponseOrganizationsInner:
        """Create an instance of ApiV1OrganizationGet200ResponseOrganizationsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if customer_id (nullable) is None
        # and __fields_set__ contains the field
        if self.customer_id is None and "customer_id" in self.__fields_set__:
            _dict['customerId'] = None

        # set to None if auth_enforced (nullable) is None
        # and __fields_set__ contains the field
        if self.auth_enforced is None and "auth_enforced" in self.__fields_set__:
            _dict['authEnforced'] = None

        # set to None if scim_enabled (nullable) is None
        # and __fields_set__ contains the field
        if self.scim_enabled is None and "scim_enabled" in self.__fields_set__:
            _dict['scimEnabled'] = None

        # set to None if kms_default_key_id (nullable) is None
        # and __fields_set__ contains the field
        if self.kms_default_key_id is None and "kms_default_key_id" in self.__fields_set__:
            _dict['kmsDefaultKeyId'] = None

        # set to None if kms_encrypted_data_key (nullable) is None
        # and __fields_set__ contains the field
        if self.kms_encrypted_data_key is None and "kms_encrypted_data_key" in self.__fields_set__:
            _dict['kmsEncryptedDataKey'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1OrganizationGet200ResponseOrganizationsInner:
        """Create an instance of ApiV1OrganizationGet200ResponseOrganizationsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1OrganizationGet200ResponseOrganizationsInner.parse_obj(obj)

        _obj = ApiV1OrganizationGet200ResponseOrganizationsInner.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "customer_id": obj.get("customerId"),
            "slug": obj.get("slug"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "auth_enforced": obj.get("authEnforced") if obj.get("authEnforced") is not None else False,
            "scim_enabled": obj.get("scimEnabled") if obj.get("scimEnabled") is not None else False,
            "kms_default_key_id": obj.get("kmsDefaultKeyId"),
            "kms_encrypted_data_key": obj.get("kmsEncryptedDataKey")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist, constr

class ApiV3SecretsBatchRawPatchRequestSecretsInner(BaseModel):
    """
    ApiV3SecretsBatchRawPatchRequestSecretsInner
    """
    secret_key: StrictStr = Field(default=..., alias="secretKey", description="The name of the secret to update.")
    secret_value: StrictStr = Field(default=..., alias="secretValue", description="The new value of the secret.")
    secret_comment: Optional[StrictStr] = Field(default=None, alias="secretComment", description="Update comment to the secret.")
    skip_multiline_encoding: Optional[StrictBool] = Field(default=None, alias="skipMultilineEncoding", description="Skip multiline encoding for the secret value.")
    new_secret_name: Optional[constr(strict=True, min_length=1)] = Field(default=None, alias="newSecretName", description="The new name for the secret")
    tag_ids: Optional[conlist(StrictStr)] = Field(default=None, alias="tagIds", description="The ID of the tags to be attached to the updated secret.")
    secret_reminder_note: Optional[StrictStr] = Field(default=None, alias="secretReminderNote", description="Note to be attached in notification email")
    secret_reminder_repeat_days: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="secretReminderRepeatDays", description="Interval for secret rotation notifications, measured in days")
    __properties = ["secretKey", "secretValue", "secretComment", "skipMultilineEncoding", "newSecretName", "tagIds", "secretReminderNote", "secretReminderRepeatDays"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV3SecretsBatchRawPatchRequestSecretsInner:
        """Create an instance of ApiV3SecretsBatchRawPatchRequestSecretsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if secret_reminder_note (nullable) is None
        # and __fields_set__ contains the field
        if self.secret_reminder_note is None and "secret_reminder_note" in self.__fields_set__:
            _dict['secretReminderNote'] = None

        # set to None if secret_reminder_repeat_days (nullable) is None
        # and __fields_set__ contains the field
        if self.secret_reminder_repeat_days is None and "secret_reminder_repeat_days" in self.__fields_set__:
            _dict['secretReminderRepeatDays'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV3SecretsBatchRawPatchRequestSecretsInner:
        """Create an instance of ApiV3SecretsBatchRawPatchRequestSecretsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV3SecretsBatchRawPatchRequestSecretsInner.parse_obj(obj)

        _obj = ApiV3SecretsBatchRawPatchRequestSecretsInner.parse_obj({
            "secret_key": obj.get("secretKey"),
            "secret_value": obj.get("secretValue"),
            "secret_comment": obj.get("secretComment"),
            "skip_multiline_encoding": obj.get("skipMultilineEncoding"),
            "new_secret_name": obj.get("newSecretName"),
            "tag_ids": obj.get("tagIds"),
            "secret_reminder_note": obj.get("secretReminderNote"),
            "secret_reminder_repeat_days": obj.get("secretReminderRepeatDays")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_workspace_get200_response_workspaces_inner import ApiV1WorkspaceGet200ResponseWorkspacesInner  # noqa: E501

class TestApiV1WorkspaceGet200ResponseWorkspacesInner(unittest.TestCase):
    """ApiV1WorkspaceGet200ResponseWorkspacesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1WorkspaceGet200ResponseWorkspacesInner:
        """Test ApiV1WorkspaceGet200ResponseWorkspacesInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1WorkspaceGet200ResponseWorkspacesInner`
        """
        model = ApiV1WorkspaceGet200ResponseWorkspacesInner()  # noqa: E501
        if include_optional:
            return ApiV1WorkspaceGet200ResponseWorkspacesInner(
                id = '',
                name = '',
                slug = '',
                auto_capitalization = True,
                org_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                version = 1.337,
                upgrade_status = '',
                pit_version_limit = 1.337,
                kms_certificate_key_id = '',
                audit_logs_retention_days = 1.337,
                id = '',
                environments = [
                    infisicalapi_client.models._api_v1_secret_imports_get_200_response_secret_imports_inner_import_env._api_v1_secret_imports_get_200_response_secretImports_inner_importEnv(
                        name = '', 
                        slug = '', 
                        id = '', )
                    ]
            )
        else:
            return ApiV1WorkspaceGet200ResponseWorkspacesInner(
                id = '',
                name = '',
                slug = '',
                org_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                environments = [
                    infisicalapi_client.models._api_v1_secret_imports_get_200_response_secret_imports_inner_import_env._api_v1_secret_imports_get_200_response_secretImports_inner_importEnv(
                        name = '', 
                        slug = '', 
                        id = '', )
                    ],
        )
        """

    def testApiV1WorkspaceGet200ResponseWorkspacesInner(self):
        """Test ApiV1WorkspaceGet200ResponseWorkspacesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt

class ApiV1RateLimitPutRequest(BaseModel):
    """
    ApiV1RateLimitPutRequest
    """
    read_rate_limit: Union[StrictFloat, StrictInt] = Field(default=..., alias="readRateLimit")
    write_rate_limit: Union[StrictFloat, StrictInt] = Field(default=..., alias="writeRateLimit")
    secrets_rate_limit: Union[StrictFloat, StrictInt] = Field(default=..., alias="secretsRateLimit")
    auth_rate_limit: Union[StrictFloat, StrictInt] = Field(default=..., alias="authRateLimit")
    invite_user_rate_limit: Union[StrictFloat, StrictInt] = Field(default=..., alias="inviteUserRateLimit")
    mfa_rate_limit: Union[StrictFloat, StrictInt] = Field(default=..., alias="mfaRateLimit")
    public_endpoint_limit: Union[StrictFloat, StrictInt] = Field(default=..., alias="publicEndpointLimit")
    __properties = ["readRateLimit", "writeRateLimit", "secretsRateLimit", "authRateLimit", "inviteUserRateLimit", "mfaRateLimit", "publicEndpointLimit"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1RateLimitPutRequest:
        """Create an instance of ApiV1RateLimitPutRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1RateLimitPutRequest:
        """Create an instance of ApiV1RateLimitPutRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1RateLimitPutRequest.parse_obj(obj)

        _obj = ApiV1RateLimitPutRequest.parse_obj({
            "read_rate_limit": obj.get("readRateLimit"),
            "write_rate_limit": obj.get("writeRateLimit"),
            "secrets_rate_limit": obj.get("secretsRateLimit"),
            "auth_rate_limit": obj.get("authRateLimit"),
            "invite_user_rate_limit": obj.get("inviteUserRateLimit"),
            "mfa_rate_limit": obj.get("mfaRateLimit"),
            "public_endpoint_limit": obj.get("publicEndpointLimit")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from infisicalapi_client.models.api_v1_secret_imports_get200_response_secret_imports_inner_import_env import ApiV1SecretImportsGet200ResponseSecretImportsInnerImportEnv

class ApiV1SecretImportsGet200ResponseSecretImportsInner(BaseModel):
    """
    ApiV1SecretImportsGet200ResponseSecretImportsInner
    """
    id: StrictStr = Field(...)
    version: Optional[Union[StrictFloat, StrictInt]] = 1
    import_path: StrictStr = Field(default=..., alias="importPath")
    position: Union[StrictFloat, StrictInt] = Field(...)
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    folder_id: StrictStr = Field(default=..., alias="folderId")
    is_replication: Optional[StrictBool] = Field(default=False, alias="isReplication")
    is_replication_success: Optional[StrictBool] = Field(default=None, alias="isReplicationSuccess")
    replication_status: Optional[StrictStr] = Field(default=None, alias="replicationStatus")
    last_replicated: Optional[datetime] = Field(default=None, alias="lastReplicated")
    is_reserved: Optional[StrictBool] = Field(default=False, alias="isReserved")
    import_env: ApiV1SecretImportsGet200ResponseSecretImportsInnerImportEnv = Field(default=..., alias="importEnv")
    __properties = ["id", "version", "importPath", "position", "createdAt", "updatedAt", "folderId", "isReplication", "isReplicationSuccess", "replicationStatus", "lastReplicated", "isReserved", "importEnv"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretImportsGet200ResponseSecretImportsInner:
        """Create an instance of ApiV1SecretImportsGet200ResponseSecretImportsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of import_env
        if self.import_env:
            _dict['importEnv'] = self.import_env.to_dict()
        # set to None if version (nullable) is None
        # and __fields_set__ contains the field
        if self.version is None and "version" in self.__fields_set__:
            _dict['version'] = None

        # set to None if is_replication (nullable) is None
        # and __fields_set__ contains the field
        if self.is_replication is None and "is_replication" in self.__fields_set__:
            _dict['isReplication'] = None

        # set to None if is_replication_success (nullable) is None
        # and __fields_set__ contains the field
        if self.is_replication_success is None and "is_replication_success" in self.__fields_set__:
            _dict['isReplicationSuccess'] = None

        # set to None if replication_status (nullable) is None
        # and __fields_set__ contains the field
        if self.replication_status is None and "replication_status" in self.__fields_set__:
            _dict['replicationStatus'] = None

        # set to None if last_replicated (nullable) is None
        # and __fields_set__ contains the field
        if self.last_replicated is None and "last_replicated" in self.__fields_set__:
            _dict['lastReplicated'] = None

        # set to None if is_reserved (nullable) is None
        # and __fields_set__ contains the field
        if self.is_reserved is None and "is_reserved" in self.__fields_set__:
            _dict['isReserved'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretImportsGet200ResponseSecretImportsInner:
        """Create an instance of ApiV1SecretImportsGet200ResponseSecretImportsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretImportsGet200ResponseSecretImportsInner.parse_obj(obj)

        _obj = ApiV1SecretImportsGet200ResponseSecretImportsInner.parse_obj({
            "id": obj.get("id"),
            "version": obj.get("version") if obj.get("version") is not None else 1,
            "import_path": obj.get("importPath"),
            "position": obj.get("position"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "folder_id": obj.get("folderId"),
            "is_replication": obj.get("isReplication") if obj.get("isReplication") is not None else False,
            "is_replication_success": obj.get("isReplicationSuccess"),
            "replication_status": obj.get("replicationStatus"),
            "last_replicated": obj.get("lastReplicated"),
            "is_reserved": obj.get("isReserved") if obj.get("isReserved") is not None else False,
            "import_env": ApiV1SecretImportsGet200ResponseSecretImportsInnerImportEnv.from_dict(obj.get("importEnv")) if obj.get("importEnv") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Optional
from pydantic import BaseModel, Field, StrictStr

class ApiV1WorkspaceWorkspaceIdAuthorizationsGet200ResponseAuthorizationsInner(BaseModel):
    """
    ApiV1WorkspaceWorkspaceIdAuthorizationsGet200ResponseAuthorizationsInner
    """
    id: StrictStr = Field(...)
    project_id: StrictStr = Field(default=..., alias="projectId")
    integration: StrictStr = Field(...)
    team_id: Optional[StrictStr] = Field(default=None, alias="teamId")
    url: Optional[StrictStr] = None
    namespace: Optional[StrictStr] = None
    account_id: Optional[StrictStr] = Field(default=None, alias="accountId")
    metadata: Optional[Any] = None
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    __properties = ["id", "projectId", "integration", "teamId", "url", "namespace", "accountId", "metadata", "createdAt", "updatedAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1WorkspaceWorkspaceIdAuthorizationsGet200ResponseAuthorizationsInner:
        """Create an instance of ApiV1WorkspaceWorkspaceIdAuthorizationsGet200ResponseAuthorizationsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if team_id (nullable) is None
        # and __fields_set__ contains the field
        if self.team_id is None and "team_id" in self.__fields_set__:
            _dict['teamId'] = None

        # set to None if url (nullable) is None
        # and __fields_set__ contains the field
        if self.url is None and "url" in self.__fields_set__:
            _dict['url'] = None

        # set to None if namespace (nullable) is None
        # and __fields_set__ contains the field
        if self.namespace is None and "namespace" in self.__fields_set__:
            _dict['namespace'] = None

        # set to None if account_id (nullable) is None
        # and __fields_set__ contains the field
        if self.account_id is None and "account_id" in self.__fields_set__:
            _dict['accountId'] = None

        # set to None if metadata (nullable) is None
        # and __fields_set__ contains the field
        if self.metadata is None and "metadata" in self.__fields_set__:
            _dict['metadata'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1WorkspaceWorkspaceIdAuthorizationsGet200ResponseAuthorizationsInner:
        """Create an instance of ApiV1WorkspaceWorkspaceIdAuthorizationsGet200ResponseAuthorizationsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1WorkspaceWorkspaceIdAuthorizationsGet200ResponseAuthorizationsInner.parse_obj(obj)

        _obj = ApiV1WorkspaceWorkspaceIdAuthorizationsGet200ResponseAuthorizationsInner.parse_obj({
            "id": obj.get("id"),
            "project_id": obj.get("projectId"),
            "integration": obj.get("integration"),
            "team_id": obj.get("teamId"),
            "url": obj.get("url"),
            "namespace": obj.get("namespace"),
            "account_id": obj.get("accountId"),
            "metadata": obj.get("metadata"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_integration_post_request_metadata import ApiV1IntegrationPostRequestMetadata  # noqa: E501

class TestApiV1IntegrationPostRequestMetadata(unittest.TestCase):
    """ApiV1IntegrationPostRequestMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1IntegrationPostRequestMetadata:
        """Test ApiV1IntegrationPostRequestMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1IntegrationPostRequestMetadata`
        """
        model = ApiV1IntegrationPostRequestMetadata()  # noqa: E501
        if include_optional:
            return ApiV1IntegrationPostRequestMetadata(
                secret_prefix = '',
                secret_suffix = '',
                initial_sync_behavior = '',
                mapping_behavior = 'one-to-one',
                should_auto_redeploy = True,
                secret_gcp_label = infisicalapi_client.models._api_v1_integration_post_request_metadata_secret_gcp_label._api_v1_integration_post_request_metadata_secretGCPLabel(
                    label_name = '', 
                    label_value = '', ),
                secret_aws_tag = [
                    infisicalapi_client.models._api_v1_audit_log_streams__id__get_200_response_audit_log_stream_headers_inner._api_v1_audit_log_streams__id__get_200_response_auditLogStream_headers_inner(
                        key = '', 
                        value = '', )
                    ],
                kms_key_id = '',
                should_disable_delete = True,
                should_enable_delete = True,
                should_mask_secrets = True,
                should_protect_secrets = True
            )
        else:
            return ApiV1IntegrationPostRequestMetadata(
        )
        """

    def testApiV1IntegrationPostRequestMetadata(self):
        """Test ApiV1IntegrationPostRequestMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1SsoOidcConfigPatch200Response(BaseModel):
    """
    ApiV1SsoOidcConfigPatch200Response
    """
    id: StrictStr = Field(...)
    issuer: Optional[StrictStr] = None
    authorization_endpoint: Optional[StrictStr] = Field(default=None, alias="authorizationEndpoint")
    configuration_type: StrictStr = Field(default=..., alias="configurationType")
    discovery_url: Optional[StrictStr] = Field(default=None, alias="discoveryURL")
    jwks_uri: Optional[StrictStr] = Field(default=None, alias="jwksUri")
    token_endpoint: Optional[StrictStr] = Field(default=None, alias="tokenEndpoint")
    userinfo_endpoint: Optional[StrictStr] = Field(default=None, alias="userinfoEndpoint")
    org_id: StrictStr = Field(default=..., alias="orgId")
    allowed_email_domains: Optional[StrictStr] = Field(default=None, alias="allowedEmailDomains")
    is_active: StrictBool = Field(default=..., alias="isActive")
    __properties = ["id", "issuer", "authorizationEndpoint", "configurationType", "discoveryURL", "jwksUri", "tokenEndpoint", "userinfoEndpoint", "orgId", "allowedEmailDomains", "isActive"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SsoOidcConfigPatch200Response:
        """Create an instance of ApiV1SsoOidcConfigPatch200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if issuer (nullable) is None
        # and __fields_set__ contains the field
        if self.issuer is None and "issuer" in self.__fields_set__:
            _dict['issuer'] = None

        # set to None if authorization_endpoint (nullable) is None
        # and __fields_set__ contains the field
        if self.authorization_endpoint is None and "authorization_endpoint" in self.__fields_set__:
            _dict['authorizationEndpoint'] = None

        # set to None if discovery_url (nullable) is None
        # and __fields_set__ contains the field
        if self.discovery_url is None and "discovery_url" in self.__fields_set__:
            _dict['discoveryURL'] = None

        # set to None if jwks_uri (nullable) is None
        # and __fields_set__ contains the field
        if self.jwks_uri is None and "jwks_uri" in self.__fields_set__:
            _dict['jwksUri'] = None

        # set to None if token_endpoint (nullable) is None
        # and __fields_set__ contains the field
        if self.token_endpoint is None and "token_endpoint" in self.__fields_set__:
            _dict['tokenEndpoint'] = None

        # set to None if userinfo_endpoint (nullable) is None
        # and __fields_set__ contains the field
        if self.userinfo_endpoint is None and "userinfo_endpoint" in self.__fields_set__:
            _dict['userinfoEndpoint'] = None

        # set to None if allowed_email_domains (nullable) is None
        # and __fields_set__ contains the field
        if self.allowed_email_domains is None and "allowed_email_domains" in self.__fields_set__:
            _dict['allowedEmailDomains'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SsoOidcConfigPatch200Response:
        """Create an instance of ApiV1SsoOidcConfigPatch200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SsoOidcConfigPatch200Response.parse_obj(obj)

        _obj = ApiV1SsoOidcConfigPatch200Response.parse_obj({
            "id": obj.get("id"),
            "issuer": obj.get("issuer"),
            "authorization_endpoint": obj.get("authorizationEndpoint"),
            "configuration_type": obj.get("configurationType"),
            "discovery_url": obj.get("discoveryURL"),
            "jwks_uri": obj.get("jwksUri"),
            "token_endpoint": obj.get("tokenEndpoint"),
            "userinfo_endpoint": obj.get("userinfoEndpoint"),
            "org_id": obj.get("orgId"),
            "allowed_email_domains": obj.get("allowedEmailDomains"),
            "is_active": obj.get("isActive")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v3_secrets_raw_secret_name_get200_response import ApiV3SecretsRawSecretNameGet200Response  # noqa: E501

class TestApiV3SecretsRawSecretNameGet200Response(unittest.TestCase):
    """ApiV3SecretsRawSecretNameGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV3SecretsRawSecretNameGet200Response:
        """Test ApiV3SecretsRawSecretNameGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV3SecretsRawSecretNameGet200Response`
        """
        model = ApiV3SecretsRawSecretNameGet200Response()  # noqa: E501
        if include_optional:
            return ApiV3SecretsRawSecretNameGet200Response(
                secret = infisicalapi_client.models._api_v3_secrets_raw__secret_name__get_200_response_secret._api_v3_secrets_raw__secretName__get_200_response_secret(
                    id = '', 
                    _id = '', 
                    workspace = '', 
                    environment = '', 
                    version = 1.337, 
                    type = '', 
                    secret_key = '', 
                    secret_value = '', 
                    secret_comment = '', 
                    secret_reminder_note = '', 
                    secret_reminder_repeat_days = 1.337, 
                    skip_multiline_encoding = True, 
                    metadata = null, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    tags = [
                        infisicalapi_client.models._api_v3_secrets_tags__secret_name__post_200_response_secret_tags_inner._api_v3_secrets_tags__secretName__post_200_response_secret_tags_inner(
                            id = '', 
                            slug = '', 
                            color = '', 
                            name = '', )
                        ], )
            )
        else:
            return ApiV3SecretsRawSecretNameGet200Response(
                secret = infisicalapi_client.models._api_v3_secrets_raw__secret_name__get_200_response_secret._api_v3_secrets_raw__secretName__get_200_response_secret(
                    id = '', 
                    _id = '', 
                    workspace = '', 
                    environment = '', 
                    version = 1.337, 
                    type = '', 
                    secret_key = '', 
                    secret_value = '', 
                    secret_comment = '', 
                    secret_reminder_note = '', 
                    secret_reminder_repeat_days = 1.337, 
                    skip_multiline_encoding = True, 
                    metadata = null, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    tags = [
                        infisicalapi_client.models._api_v3_secrets_tags__secret_name__post_200_response_secret_tags_inner._api_v3_secrets_tags__secretName__post_200_response_secret_tags_inner(
                            id = '', 
                            slug = '', 
                            color = '', 
                            name = '', )
                        ], ),
        )
        """

    def testApiV3SecretsRawSecretNameGet200Response(self):
        """Test ApiV3SecretsRawSecretNameGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_membership_id_get200_response import ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response  # noqa: E501

class TestApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response(unittest.TestCase):
    """ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response:
        """Test ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response`
        """
        model = ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response()  # noqa: E501
        if include_optional:
            return ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response(
                membership = infisicalapi_client.models._api_v2_organizations__organization_id__memberships__membership_id__get_200_response_membership._api_v2_organizations__organizationId__memberships__membershipId__get_200_response_membership(
                    id = '', 
                    role = '', 
                    status = 'invited', 
                    invite_email = '', 
                    user_id = '', 
                    org_id = '', 
                    role_id = '', 
                    project_favorites = [
                        ''
                        ], 
                    is_active = True, 
                    user = infisicalapi_client.models._api_v2_organizations__organization_id__memberships__membership_id__get_200_response_membership_user._api_v2_organizations__organizationId__memberships__membershipId__get_200_response_membership_user(
                        username = '', 
                        email = '', 
                        is_email_verified = True, 
                        first_name = '', 
                        last_name = '', 
                        id = '', 
                        public_key = '', ), )
            )
        else:
            return ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response(
                membership = infisicalapi_client.models._api_v2_organizations__organization_id__memberships__membership_id__get_200_response_membership._api_v2_organizations__organizationId__memberships__membershipId__get_200_response_membership(
                    id = '', 
                    role = '', 
                    status = 'invited', 
                    invite_email = '', 
                    user_id = '', 
                    org_id = '', 
                    role_id = '', 
                    project_favorites = [
                        ''
                        ], 
                    is_active = True, 
                    user = infisicalapi_client.models._api_v2_organizations__organization_id__memberships__membership_id__get_200_response_membership_user._api_v2_organizations__organizationId__memberships__membershipId__get_200_response_membership_user(
                        username = '', 
                        email = '', 
                        is_email_verified = True, 
                        first_name = '', 
                        last_name = '', 
                        id = '', 
                        public_key = '', ), ),
        )
        """

    def testApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response(self):
        """Test ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist

class ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser(BaseModel):
    """
    ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser
    """
    id: StrictStr = Field(...)
    email: Optional[StrictStr] = None
    auth_methods: Optional[conlist(StrictStr)] = Field(default=None, alias="authMethods")
    super_admin: Optional[StrictBool] = Field(default=False, alias="superAdmin")
    first_name: Optional[StrictStr] = Field(default=None, alias="firstName")
    last_name: Optional[StrictStr] = Field(default=None, alias="lastName")
    is_accepted: Optional[StrictBool] = Field(default=False, alias="isAccepted")
    is_mfa_enabled: Optional[StrictBool] = Field(default=False, alias="isMfaEnabled")
    mfa_methods: Optional[conlist(StrictStr)] = Field(default=None, alias="mfaMethods")
    devices: Optional[Any] = None
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    is_ghost: Optional[StrictBool] = Field(default=False, alias="isGhost")
    username: StrictStr = Field(...)
    is_email_verified: Optional[StrictBool] = Field(default=False, alias="isEmailVerified")
    consecutive_failed_mfa_attempts: Optional[Union[StrictFloat, StrictInt]] = Field(default=0, alias="consecutiveFailedMfaAttempts")
    is_locked: Optional[StrictBool] = Field(default=False, alias="isLocked")
    temporary_lock_date_end: Optional[datetime] = Field(default=None, alias="temporaryLockDateEnd")
    consecutive_failed_password_attempts: Optional[Union[StrictFloat, StrictInt]] = Field(default=0, alias="consecutiveFailedPasswordAttempts")
    __properties = ["id", "email", "authMethods", "superAdmin", "firstName", "lastName", "isAccepted", "isMfaEnabled", "mfaMethods", "devices", "createdAt", "updatedAt", "isGhost", "username", "isEmailVerified", "consecutiveFailedMfaAttempts", "isLocked", "temporaryLockDateEnd", "consecutiveFailedPasswordAttempts"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser:
        """Create an instance of ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if email (nullable) is None
        # and __fields_set__ contains the field
        if self.email is None and "email" in self.__fields_set__:
            _dict['email'] = None

        # set to None if auth_methods (nullable) is None
        # and __fields_set__ contains the field
        if self.auth_methods is None and "auth_methods" in self.__fields_set__:
            _dict['authMethods'] = None

        # set to None if super_admin (nullable) is None
        # and __fields_set__ contains the field
        if self.super_admin is None and "super_admin" in self.__fields_set__:
            _dict['superAdmin'] = None

        # set to None if first_name (nullable) is None
        # and __fields_set__ contains the field
        if self.first_name is None and "first_name" in self.__fields_set__:
            _dict['firstName'] = None

        # set to None if last_name (nullable) is None
        # and __fields_set__ contains the field
        if self.last_name is None and "last_name" in self.__fields_set__:
            _dict['lastName'] = None

        # set to None if is_accepted (nullable) is None
        # and __fields_set__ contains the field
        if self.is_accepted is None and "is_accepted" in self.__fields_set__:
            _dict['isAccepted'] = None

        # set to None if is_mfa_enabled (nullable) is None
        # and __fields_set__ contains the field
        if self.is_mfa_enabled is None and "is_mfa_enabled" in self.__fields_set__:
            _dict['isMfaEnabled'] = None

        # set to None if mfa_methods (nullable) is None
        # and __fields_set__ contains the field
        if self.mfa_methods is None and "mfa_methods" in self.__fields_set__:
            _dict['mfaMethods'] = None

        # set to None if devices (nullable) is None
        # and __fields_set__ contains the field
        if self.devices is None and "devices" in self.__fields_set__:
            _dict['devices'] = None

        # set to None if is_email_verified (nullable) is None
        # and __fields_set__ contains the field
        if self.is_email_verified is None and "is_email_verified" in self.__fields_set__:
            _dict['isEmailVerified'] = None

        # set to None if consecutive_failed_mfa_attempts (nullable) is None
        # and __fields_set__ contains the field
        if self.consecutive_failed_mfa_attempts is None and "consecutive_failed_mfa_attempts" in self.__fields_set__:
            _dict['consecutiveFailedMfaAttempts'] = None

        # set to None if is_locked (nullable) is None
        # and __fields_set__ contains the field
        if self.is_locked is None and "is_locked" in self.__fields_set__:
            _dict['isLocked'] = None

        # set to None if temporary_lock_date_end (nullable) is None
        # and __fields_set__ contains the field
        if self.temporary_lock_date_end is None and "temporary_lock_date_end" in self.__fields_set__:
            _dict['temporaryLockDateEnd'] = None

        # set to None if consecutive_failed_password_attempts (nullable) is None
        # and __fields_set__ contains the field
        if self.consecutive_failed_password_attempts is None and "consecutive_failed_password_attempts" in self.__fields_set__:
            _dict['consecutiveFailedPasswordAttempts'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser:
        """Create an instance of ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser.parse_obj(obj)

        _obj = ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser.parse_obj({
            "id": obj.get("id"),
            "email": obj.get("email"),
            "auth_methods": obj.get("authMethods"),
            "super_admin": obj.get("superAdmin") if obj.get("superAdmin") is not None else False,
            "first_name": obj.get("firstName"),
            "last_name": obj.get("lastName"),
            "is_accepted": obj.get("isAccepted") if obj.get("isAccepted") is not None else False,
            "is_mfa_enabled": obj.get("isMfaEnabled") if obj.get("isMfaEnabled") is not None else False,
            "mfa_methods": obj.get("mfaMethods"),
            "devices": obj.get("devices"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "is_ghost": obj.get("isGhost") if obj.get("isGhost") is not None else False,
            "username": obj.get("username"),
            "is_email_verified": obj.get("isEmailVerified") if obj.get("isEmailVerified") is not None else False,
            "consecutive_failed_mfa_attempts": obj.get("consecutiveFailedMfaAttempts") if obj.get("consecutiveFailedMfaAttempts") is not None else 0,
            "is_locked": obj.get("isLocked") if obj.get("isLocked") is not None else False,
            "temporary_lock_date_end": obj.get("temporaryLockDateEnd"),
            "consecutive_failed_password_attempts": obj.get("consecutiveFailedPasswordAttempts") if obj.get("consecutiveFailedPasswordAttempts") is not None else 0
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr

class ApiV1PkiCaCaIdSignCertificatePostRequest(BaseModel):
    """
    ApiV1PkiCaCaIdSignCertificatePostRequest
    """
    csr: constr(strict=True, min_length=1) = Field(default=..., description="The pem-encoded CSR to sign with the CA to be used for certificate issuance")
    friendly_name: Optional[StrictStr] = Field(default=None, alias="friendlyName", description="A friendly name for the certificate")
    common_name: Optional[constr(strict=True, min_length=1)] = Field(default=None, alias="commonName", description="The common name (CN) for the certificate")
    alt_names: Optional[StrictStr] = Field(default='', alias="altNames", description="A comma-delimited list of Subject Alternative Names (SANs) for the certificate; these can be host names or email addresses.")
    ttl: StrictStr = Field(default=..., description="The time to live for the certificate such as 1m, 1h, 1d, 1y, ...")
    not_before: Optional[StrictStr] = Field(default=None, alias="notBefore", description="The date and time when the certificate becomes valid in YYYY-MM-DDTHH:mm:ss.sssZ format")
    not_after: Optional[StrictStr] = Field(default=None, alias="notAfter", description="The date and time when the certificate expires in YYYY-MM-DDTHH:mm:ss.sssZ format")
    __properties = ["csr", "friendlyName", "commonName", "altNames", "ttl", "notBefore", "notAfter"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1PkiCaCaIdSignCertificatePostRequest:
        """Create an instance of ApiV1PkiCaCaIdSignCertificatePostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1PkiCaCaIdSignCertificatePostRequest:
        """Create an instance of ApiV1PkiCaCaIdSignCertificatePostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1PkiCaCaIdSignCertificatePostRequest.parse_obj(obj)

        _obj = ApiV1PkiCaCaIdSignCertificatePostRequest.parse_obj({
            "csr": obj.get("csr"),
            "friendly_name": obj.get("friendlyName"),
            "common_name": obj.get("commonName"),
            "alt_names": obj.get("altNames") if obj.get("altNames") is not None else '',
            "ttl": obj.get("ttl"),
            "not_before": obj.get("notBefore"),
            "not_after": obj.get("notAfter")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_sso_oidc_config_post_request import ApiV1SsoOidcConfigPostRequest  # noqa: E501

class TestApiV1SsoOidcConfigPostRequest(unittest.TestCase):
    """ApiV1SsoOidcConfigPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SsoOidcConfigPostRequest:
        """Test ApiV1SsoOidcConfigPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SsoOidcConfigPostRequest`
        """
        model = ApiV1SsoOidcConfigPostRequest()  # noqa: E501
        if include_optional:
            return ApiV1SsoOidcConfigPostRequest(
                allowed_email_domains = '',
                configuration_type = 'custom',
                issuer = '',
                discovery_url = '',
                authorization_endpoint = '',
                jwks_uri = '',
                token_endpoint = '',
                userinfo_endpoint = '',
                client_id = '',
                client_secret = '',
                is_active = True,
                org_slug = ''
            )
        else:
            return ApiV1SsoOidcConfigPostRequest(
                configuration_type = 'custom',
                client_id = '',
                client_secret = '',
                is_active = True,
                org_slug = '',
        )
        """

    def testApiV1SsoOidcConfigPostRequest(self):
        """Test ApiV1SsoOidcConfigPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1SsoConfigPost200Response(BaseModel):
    """
    ApiV1SsoConfigPost200Response
    """
    id: StrictStr = Field(...)
    auth_provider: StrictStr = Field(default=..., alias="authProvider")
    is_active: StrictBool = Field(default=..., alias="isActive")
    encrypted_entry_point: Optional[StrictStr] = Field(default=None, alias="encryptedEntryPoint")
    entry_point_iv: Optional[StrictStr] = Field(default=None, alias="entryPointIV")
    entry_point_tag: Optional[StrictStr] = Field(default=None, alias="entryPointTag")
    encrypted_issuer: Optional[StrictStr] = Field(default=None, alias="encryptedIssuer")
    issuer_tag: Optional[StrictStr] = Field(default=None, alias="issuerTag")
    issuer_iv: Optional[StrictStr] = Field(default=None, alias="issuerIV")
    encrypted_cert: Optional[StrictStr] = Field(default=None, alias="encryptedCert")
    cert_iv: Optional[StrictStr] = Field(default=None, alias="certIV")
    cert_tag: Optional[StrictStr] = Field(default=None, alias="certTag")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    org_id: StrictStr = Field(default=..., alias="orgId")
    last_used: Optional[datetime] = Field(default=None, alias="lastUsed")
    __properties = ["id", "authProvider", "isActive", "encryptedEntryPoint", "entryPointIV", "entryPointTag", "encryptedIssuer", "issuerTag", "issuerIV", "encryptedCert", "certIV", "certTag", "createdAt", "updatedAt", "orgId", "lastUsed"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SsoConfigPost200Response:
        """Create an instance of ApiV1SsoConfigPost200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if encrypted_entry_point (nullable) is None
        # and __fields_set__ contains the field
        if self.encrypted_entry_point is None and "encrypted_entry_point" in self.__fields_set__:
            _dict['encryptedEntryPoint'] = None

        # set to None if entry_point_iv (nullable) is None
        # and __fields_set__ contains the field
        if self.entry_point_iv is None and "entry_point_iv" in self.__fields_set__:
            _dict['entryPointIV'] = None

        # set to None if entry_point_tag (nullable) is None
        # and __fields_set__ contains the field
        if self.entry_point_tag is None and "entry_point_tag" in self.__fields_set__:
            _dict['entryPointTag'] = None

        # set to None if encrypted_issuer (nullable) is None
        # and __fields_set__ contains the field
        if self.encrypted_issuer is None and "encrypted_issuer" in self.__fields_set__:
            _dict['encryptedIssuer'] = None

        # set to None if issuer_tag (nullable) is None
        # and __fields_set__ contains the field
        if self.issuer_tag is None and "issuer_tag" in self.__fields_set__:
            _dict['issuerTag'] = None

        # set to None if issuer_iv (nullable) is None
        # and __fields_set__ contains the field
        if self.issuer_iv is None and "issuer_iv" in self.__fields_set__:
            _dict['issuerIV'] = None

        # set to None if encrypted_cert (nullable) is None
        # and __fields_set__ contains the field
        if self.encrypted_cert is None and "encrypted_cert" in self.__fields_set__:
            _dict['encryptedCert'] = None

        # set to None if cert_iv (nullable) is None
        # and __fields_set__ contains the field
        if self.cert_iv is None and "cert_iv" in self.__fields_set__:
            _dict['certIV'] = None

        # set to None if cert_tag (nullable) is None
        # and __fields_set__ contains the field
        if self.cert_tag is None and "cert_tag" in self.__fields_set__:
            _dict['certTag'] = None

        # set to None if last_used (nullable) is None
        # and __fields_set__ contains the field
        if self.last_used is None and "last_used" in self.__fields_set__:
            _dict['lastUsed'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SsoConfigPost200Response:
        """Create an instance of ApiV1SsoConfigPost200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SsoConfigPost200Response.parse_obj(obj)

        _obj = ApiV1SsoConfigPost200Response.parse_obj({
            "id": obj.get("id"),
            "auth_provider": obj.get("authProvider"),
            "is_active": obj.get("isActive"),
            "encrypted_entry_point": obj.get("encryptedEntryPoint"),
            "entry_point_iv": obj.get("entryPointIV"),
            "entry_point_tag": obj.get("entryPointTag"),
            "encrypted_issuer": obj.get("encryptedIssuer"),
            "issuer_tag": obj.get("issuerTag"),
            "issuer_iv": obj.get("issuerIV"),
            "encrypted_cert": obj.get("encryptedCert"),
            "cert_iv": obj.get("certIV"),
            "cert_tag": obj.get("certTag"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "org_id": obj.get("orgId"),
            "last_used": obj.get("lastUsed")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_scanning_organization_organization_id_risks_get200_response_risks_inner import ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner  # noqa: E501

class TestApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner(unittest.TestCase):
    """ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner:
        """Test ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner`
        """
        model = ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner()  # noqa: E501
        if include_optional:
            return ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner(
                id = '',
                description = '',
                start_line = '',
                end_line = '',
                start_column = '',
                end_column = '',
                file = '',
                symlink_file = '',
                commit = '',
                entropy = '',
                author = '',
                email = '',
                var_date = '',
                message = '',
                tags = [
                    ''
                    ],
                rule_id = '',
                fingerprint = '',
                finger_print_without_commit_id = '',
                is_false_positive = True,
                is_resolved = True,
                risk_owner = '',
                installation_id = '',
                repository_id = '',
                repository_link = '',
                repository_full_name = '',
                pusher_name = '',
                pusher_email = '',
                status = '',
                org_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner(
                id = '',
                installation_id = '',
                org_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner(self):
        """Test ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v2_workspace_project_slug_groups_get200_response import ApiV2WorkspaceProjectSlugGroupsGet200Response  # noqa: E501

class TestApiV2WorkspaceProjectSlugGroupsGet200Response(unittest.TestCase):
    """ApiV2WorkspaceProjectSlugGroupsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV2WorkspaceProjectSlugGroupsGet200Response:
        """Test ApiV2WorkspaceProjectSlugGroupsGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV2WorkspaceProjectSlugGroupsGet200Response`
        """
        model = ApiV2WorkspaceProjectSlugGroupsGet200Response()  # noqa: E501
        if include_optional:
            return ApiV2WorkspaceProjectSlugGroupsGet200Response(
                group_memberships = [
                    infisicalapi_client.models._api_v2_workspace__project_slug__groups_get_200_response_group_memberships_inner._api_v2_workspace__projectSlug__groups_get_200_response_groupMemberships_inner(
                        id = '', 
                        group_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        roles = [
                            infisicalapi_client.models._api_v1_workspace__workspace_id__users_get_200_response_users_inner_roles_inner._api_v1_workspace__workspaceId__users_get_200_response_users_inner_roles_inner(
                                id = '', 
                                role = '', 
                                custom_role_id = '', 
                                custom_role_name = '', 
                                custom_role_slug = '', 
                                is_temporary = True, 
                                temporary_mode = '', 
                                temporary_range = '', 
                                temporary_access_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                temporary_access_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        group = infisicalapi_client.models._api_v2_workspace__project_slug__groups_get_200_response_group_memberships_inner_group._api_v2_workspace__projectSlug__groups_get_200_response_groupMemberships_inner_group(
                            name = '', 
                            id = '', 
                            slug = '', ), )
                    ]
            )
        else:
            return ApiV2WorkspaceProjectSlugGroupsGet200Response(
                group_memberships = [
                    infisicalapi_client.models._api_v2_workspace__project_slug__groups_get_200_response_group_memberships_inner._api_v2_workspace__projectSlug__groups_get_200_response_groupMemberships_inner(
                        id = '', 
                        group_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        roles = [
                            infisicalapi_client.models._api_v1_workspace__workspace_id__users_get_200_response_users_inner_roles_inner._api_v1_workspace__workspaceId__users_get_200_response_users_inner_roles_inner(
                                id = '', 
                                role = '', 
                                custom_role_id = '', 
                                custom_role_name = '', 
                                custom_role_slug = '', 
                                is_temporary = True, 
                                temporary_mode = '', 
                                temporary_range = '', 
                                temporary_access_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                temporary_access_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        group = infisicalapi_client.models._api_v2_workspace__project_slug__groups_get_200_response_group_memberships_inner_group._api_v2_workspace__projectSlug__groups_get_200_response_groupMemberships_inner_group(
                            name = '', 
                            id = '', 
                            slug = '', ), )
                    ],
        )
        """

    def testApiV2WorkspaceProjectSlugGroupsGet200Response(self):
        """Test ApiV2WorkspaceProjectSlugGroupsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_external_kms_get200_response_external_kms_list_inner import ApiV1ExternalKmsGet200ResponseExternalKmsListInner  # noqa: E501

class TestApiV1ExternalKmsGet200ResponseExternalKmsListInner(unittest.TestCase):
    """ApiV1ExternalKmsGet200ResponseExternalKmsListInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1ExternalKmsGet200ResponseExternalKmsListInner:
        """Test ApiV1ExternalKmsGet200ResponseExternalKmsListInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1ExternalKmsGet200ResponseExternalKmsListInner`
        """
        model = ApiV1ExternalKmsGet200ResponseExternalKmsListInner()  # noqa: E501
        if include_optional:
            return ApiV1ExternalKmsGet200ResponseExternalKmsListInner(
                id = '',
                description = '',
                is_disabled = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                slug = '',
                external_kms = infisicalapi_client.models._api_v1_external_kms_get_200_response_external_kms_list_inner_external_kms._api_v1_external_kms_get_200_response_externalKmsList_inner_externalKms(
                    provider = '', 
                    status = '', 
                    status_details = '', )
            )
        else:
            return ApiV1ExternalKmsGet200ResponseExternalKmsListInner(
                id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                slug = '',
                external_kms = infisicalapi_client.models._api_v1_external_kms_get_200_response_external_kms_list_inner_external_kms._api_v1_external_kms_get_200_response_externalKmsList_inner_externalKms(
                    provider = '', 
                    status = '', 
                    status_details = '', ),
        )
        """

    def testApiV1ExternalKmsGet200ResponseExternalKmsListInner(self):
        """Test ApiV1ExternalKmsGet200ResponseExternalKmsListInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_auth_azure_auth_identities_identity_id_patch_request import ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest  # noqa: E501

class TestApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest(unittest.TestCase):
    """ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest:
        """Test ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest`
        """
        model = ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest()  # noqa: E501
        if include_optional:
            return ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest(
                tenant_id = '',
                resource = '',
                allowed_service_principal_ids = '',
                access_token_trusted_ips = [
                    infisicalapi_client.models._api_v1_auth_token_auth_identities__identity_id__post_request_access_token_trusted_ips_inner._api_v1_auth_token_auth_identities__identityId__post_request_accessTokenTrustedIps_inner(
                        ip_address = '', )
                    ],
                access_token_ttl = 0,
                access_token_num_uses_limit = 0,
                access_token_max_ttl = 56
            )
        else:
            return ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest(
        )
        """

    def testApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest(self):
        """Test ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr

class ApiV1DynamicSecretsPostRequestProviderAnyOf2Inputs(BaseModel):
    """
    ApiV1DynamicSecretsPostRequestProviderAnyOf2Inputs
    """
    access_key: constr(strict=True, min_length=1) = Field(default=..., alias="accessKey")
    secret_access_key: constr(strict=True, min_length=1) = Field(default=..., alias="secretAccessKey")
    region: constr(strict=True, min_length=1) = Field(...)
    aws_path: Optional[StrictStr] = Field(default=None, alias="awsPath")
    permission_boundary_policy_arn: Optional[StrictStr] = Field(default=None, alias="permissionBoundaryPolicyArn")
    policy_document: Optional[StrictStr] = Field(default=None, alias="policyDocument")
    user_groups: Optional[StrictStr] = Field(default=None, alias="userGroups")
    policy_arns: Optional[StrictStr] = Field(default=None, alias="policyArns")
    __properties = ["accessKey", "secretAccessKey", "region", "awsPath", "permissionBoundaryPolicyArn", "policyDocument", "userGroups", "policyArns"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1DynamicSecretsPostRequestProviderAnyOf2Inputs:
        """Create an instance of ApiV1DynamicSecretsPostRequestProviderAnyOf2Inputs from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1DynamicSecretsPostRequestProviderAnyOf2Inputs:
        """Create an instance of ApiV1DynamicSecretsPostRequestProviderAnyOf2Inputs from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1DynamicSecretsPostRequestProviderAnyOf2Inputs.parse_obj(obj)

        _obj = ApiV1DynamicSecretsPostRequestProviderAnyOf2Inputs.parse_obj({
            "access_key": obj.get("accessKey"),
            "secret_access_key": obj.get("secretAccessKey"),
            "region": obj.get("region"),
            "aws_path": obj.get("awsPath"),
            "permission_boundary_policy_arn": obj.get("permissionBoundaryPolicyArn"),
            "policy_document": obj.get("policyDocument"),
            "user_groups": obj.get("userGroups"),
            "policy_arns": obj.get("policyArns")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1SecretApprovalRequestsIdMergePost200ResponseApproval(BaseModel):
    """
    ApiV1SecretApprovalRequestsIdMergePost200ResponseApproval
    """
    id: StrictStr = Field(...)
    policy_id: StrictStr = Field(default=..., alias="policyId")
    has_merged: Optional[StrictBool] = Field(default=False, alias="hasMerged")
    status: Optional[StrictStr] = 'open'
    conflicts: Optional[Any] = None
    slug: StrictStr = Field(...)
    folder_id: StrictStr = Field(default=..., alias="folderId")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    is_replicated: Optional[StrictBool] = Field(default=None, alias="isReplicated")
    committer_user_id: StrictStr = Field(default=..., alias="committerUserId")
    status_changed_by_user_id: Optional[StrictStr] = Field(default=None, alias="statusChangedByUserId")
    bypass_reason: Optional[StrictStr] = Field(default=None, alias="bypassReason")
    __properties = ["id", "policyId", "hasMerged", "status", "conflicts", "slug", "folderId", "createdAt", "updatedAt", "isReplicated", "committerUserId", "statusChangedByUserId", "bypassReason"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretApprovalRequestsIdMergePost200ResponseApproval:
        """Create an instance of ApiV1SecretApprovalRequestsIdMergePost200ResponseApproval from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if conflicts (nullable) is None
        # and __fields_set__ contains the field
        if self.conflicts is None and "conflicts" in self.__fields_set__:
            _dict['conflicts'] = None

        # set to None if is_replicated (nullable) is None
        # and __fields_set__ contains the field
        if self.is_replicated is None and "is_replicated" in self.__fields_set__:
            _dict['isReplicated'] = None

        # set to None if status_changed_by_user_id (nullable) is None
        # and __fields_set__ contains the field
        if self.status_changed_by_user_id is None and "status_changed_by_user_id" in self.__fields_set__:
            _dict['statusChangedByUserId'] = None

        # set to None if bypass_reason (nullable) is None
        # and __fields_set__ contains the field
        if self.bypass_reason is None and "bypass_reason" in self.__fields_set__:
            _dict['bypassReason'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretApprovalRequestsIdMergePost200ResponseApproval:
        """Create an instance of ApiV1SecretApprovalRequestsIdMergePost200ResponseApproval from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretApprovalRequestsIdMergePost200ResponseApproval.parse_obj(obj)

        _obj = ApiV1SecretApprovalRequestsIdMergePost200ResponseApproval.parse_obj({
            "id": obj.get("id"),
            "policy_id": obj.get("policyId"),
            "has_merged": obj.get("hasMerged") if obj.get("hasMerged") is not None else False,
            "status": obj.get("status") if obj.get("status") is not None else 'open',
            "conflicts": obj.get("conflicts"),
            "slug": obj.get("slug"),
            "folder_id": obj.get("folderId"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "is_replicated": obj.get("isReplicated"),
            "committer_user_id": obj.get("committerUserId"),
            "status_changed_by_user_id": obj.get("statusChangedByUserId"),
            "bypass_reason": obj.get("bypassReason")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr

class ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200ResponseClientSecretDataInner(BaseModel):
    """
    ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200ResponseClientSecretDataInner
    """
    id: StrictStr = Field(...)
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    description: StrictStr = Field(...)
    client_secret_prefix: StrictStr = Field(default=..., alias="clientSecretPrefix")
    client_secret_num_uses: Optional[Union[StrictFloat, StrictInt]] = Field(default=0, alias="clientSecretNumUses")
    client_secret_num_uses_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=0, alias="clientSecretNumUsesLimit")
    client_secret_ttl: Optional[Union[StrictFloat, StrictInt]] = Field(default=0, alias="clientSecretTTL")
    identity_uaid: StrictStr = Field(default=..., alias="identityUAId")
    is_client_secret_revoked: Optional[StrictBool] = Field(default=False, alias="isClientSecretRevoked")
    __properties = ["id", "createdAt", "updatedAt", "description", "clientSecretPrefix", "clientSecretNumUses", "clientSecretNumUsesLimit", "clientSecretTTL", "identityUAId", "isClientSecretRevoked"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200ResponseClientSecretDataInner:
        """Create an instance of ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200ResponseClientSecretDataInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200ResponseClientSecretDataInner:
        """Create an instance of ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200ResponseClientSecretDataInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200ResponseClientSecretDataInner.parse_obj(obj)

        _obj = ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200ResponseClientSecretDataInner.parse_obj({
            "id": obj.get("id"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "description": obj.get("description"),
            "client_secret_prefix": obj.get("clientSecretPrefix"),
            "client_secret_num_uses": obj.get("clientSecretNumUses") if obj.get("clientSecretNumUses") is not None else 0,
            "client_secret_num_uses_limit": obj.get("clientSecretNumUsesLimit") if obj.get("clientSecretNumUsesLimit") is not None else 0,
            "client_secret_ttl": obj.get("clientSecretTTL") if obj.get("clientSecretTTL") is not None else 0,
            "identity_uaid": obj.get("identityUAId"),
            "is_client_secret_revoked": obj.get("isClientSecretRevoked") if obj.get("isClientSecretRevoked") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v2_service_token_post_request import ApiV2ServiceTokenPostRequest  # noqa: E501

class TestApiV2ServiceTokenPostRequest(unittest.TestCase):
    """ApiV2ServiceTokenPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV2ServiceTokenPostRequest:
        """Test ApiV2ServiceTokenPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV2ServiceTokenPostRequest`
        """
        model = ApiV2ServiceTokenPostRequest()  # noqa: E501
        if include_optional:
            return ApiV2ServiceTokenPostRequest(
                name = '',
                workspace_id = '',
                scopes = [
                    infisicalapi_client.models._api_v2_service_token_post_request_scopes_inner._api_v2_service_token_post_request_scopes_inner(
                        environment = '', 
                        secret_path = '', )
                    ],
                encrypted_key = '',
                iv = '',
                tag = '',
                expires_in = 1.337,
                permissions = [
                    'read'
                    ]
            )
        else:
            return ApiV2ServiceTokenPostRequest(
                name = '',
                workspace_id = '',
                scopes = [
                    infisicalapi_client.models._api_v2_service_token_post_request_scopes_inner._api_v2_service_token_post_request_scopes_inner(
                        environment = '', 
                        secret_path = '', )
                    ],
                encrypted_key = '',
                iv = '',
                tag = '',
                expires_in = 1.337,
                permissions = [
                    'read'
                    ],
        )
        """

    def testApiV2ServiceTokenPostRequest(self):
        """Test ApiV2ServiceTokenPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist
from infisicalapi_client.models.api_v1_identities_get200_response_identities_inner_identity import ApiV1IdentitiesGet200ResponseIdentitiesInnerIdentity
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response_users_inner_project import ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerProject
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response_users_inner_roles_inner import ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner

class ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner(BaseModel):
    """
    ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner
    """
    id: StrictStr = Field(...)
    identity_id: StrictStr = Field(default=..., alias="identityId")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    roles: conlist(ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner) = Field(...)
    identity: ApiV1IdentitiesGet200ResponseIdentitiesInnerIdentity = Field(...)
    project: ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerProject = Field(...)
    __properties = ["id", "identityId", "createdAt", "updatedAt", "roles", "identity", "project"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner:
        """Create an instance of ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in roles (list)
        _items = []
        if self.roles:
            for _item in self.roles:
                if _item:
                    _items.append(_item.to_dict())
            _dict['roles'] = _items
        # override the default output from pydantic by calling `to_dict()` of identity
        if self.identity:
            _dict['identity'] = self.identity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner:
        """Create an instance of ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner.parse_obj(obj)

        _obj = ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner.parse_obj({
            "id": obj.get("id"),
            "identity_id": obj.get("identityId"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "roles": [ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner.from_dict(_item) for _item in obj.get("roles")] if obj.get("roles") is not None else None,
            "identity": ApiV1IdentitiesGet200ResponseIdentitiesInnerIdentity.from_dict(obj.get("identity")) if obj.get("identity") is not None else None,
            "project": ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerProject.from_dict(obj.get("project")) if obj.get("project") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr

class ApiV1DynamicSecretsLeasesPostRequest(BaseModel):
    """
    ApiV1DynamicSecretsLeasesPostRequest
    """
    dynamic_secret_name: constr(strict=True, min_length=1) = Field(default=..., alias="dynamicSecretName", description="The name of the dynamic secret.")
    project_slug: constr(strict=True, min_length=1) = Field(default=..., alias="projectSlug", description="The slug of the project of the dynamic secret in.")
    ttl: Optional[StrictStr] = Field(default=None, description="The lease lifetime ttl. If not provided the default TTL of dynamic secret will be used.")
    path: Optional[StrictStr] = Field(default='/', description="The path of the dynamic secret in.")
    environment_slug: constr(strict=True, min_length=1) = Field(default=..., alias="environmentSlug", description="The path of the dynamic secret in.")
    __properties = ["dynamicSecretName", "projectSlug", "ttl", "path", "environmentSlug"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1DynamicSecretsLeasesPostRequest:
        """Create an instance of ApiV1DynamicSecretsLeasesPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1DynamicSecretsLeasesPostRequest:
        """Create an instance of ApiV1DynamicSecretsLeasesPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1DynamicSecretsLeasesPostRequest.parse_obj(obj)

        _obj = ApiV1DynamicSecretsLeasesPostRequest.parse_obj({
            "dynamic_secret_name": obj.get("dynamicSecretName"),
            "project_slug": obj.get("projectSlug"),
            "ttl": obj.get("ttl"),
            "path": obj.get("path") if obj.get("path") is not None else '/',
            "environment_slug": obj.get("environmentSlug")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_scim_groups_get200_response import ApiV1ScimGroupsGet200Response  # noqa: E501

class TestApiV1ScimGroupsGet200Response(unittest.TestCase):
    """ApiV1ScimGroupsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1ScimGroupsGet200Response:
        """Test ApiV1ScimGroupsGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1ScimGroupsGet200Response`
        """
        model = ApiV1ScimGroupsGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1ScimGroupsGet200Response(
                resources = [
                    infisicalapi_client.models._api_v1_scim_groups_get_200_response_resources_inner._api_v1_scim_Groups_get_200_response_Resources_inner(
                        schemas = [
                            ''
                            ], 
                        id = '', 
                        display_name = '', 
                        members = [
                            infisicalapi_client.models._api_v1_scim_users__org_membership_id__get_201_response_groups_inner._api_v1_scim_Users__orgMembershipId__get_201_response_groups_inner(
                                value = '', 
                                display = '', )
                            ], 
                        meta = infisicalapi_client.models._api_v1_scim_groups_get_200_response_resources_inner_meta._api_v1_scim_Groups_get_200_response_Resources_inner_meta(
                            resource_type = '', ), )
                    ],
                items_per_page = 1.337,
                schemas = [
                    ''
                    ],
                start_index = 1.337,
                total_results = 1.337
            )
        else:
            return ApiV1ScimGroupsGet200Response(
                resources = [
                    infisicalapi_client.models._api_v1_scim_groups_get_200_response_resources_inner._api_v1_scim_Groups_get_200_response_Resources_inner(
                        schemas = [
                            ''
                            ], 
                        id = '', 
                        display_name = '', 
                        members = [
                            infisicalapi_client.models._api_v1_scim_users__org_membership_id__get_201_response_groups_inner._api_v1_scim_Users__orgMembershipId__get_201_response_groups_inner(
                                value = '', 
                                display = '', )
                            ], 
                        meta = infisicalapi_client.models._api_v1_scim_groups_get_200_response_resources_inner_meta._api_v1_scim_Groups_get_200_response_Resources_inner_meta(
                            resource_type = '', ), )
                    ],
                items_per_page = 1.337,
                schemas = [
                    ''
                    ],
                start_index = 1.337,
                total_results = 1.337,
        )
        """

    def testApiV1ScimGroupsGet200Response(self):
        """Test ApiV1ScimGroupsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
